==> sword_1.5.3.orig.tar.gz: sword-1.5.3.orig/apps/windoze/CBuilder5/BibleCS/editentryfrm.h <==
//----------------------------------------------------------------------------
//Borland C++Builder
//Copyright (c) 1987, 1998 Borland International Inc. All Rights Reserved.
//----------------------------------------------------------------------------
//----------------------------------------------------------------------------
#ifndef editentryfrmH
#define editentryfrmH
//----------------------------------------------------------------------------
#include <Outline.hpp>
#include <Grids.hpp>
#include <Buttons.hpp>
#include <ExtCtrls.hpp>
#include <StdCtrls.hpp>
#include <ComCtrls.hpp>
#include <Menus.hpp>
#include <Dialogs.hpp>
#include <Forms.hpp>
#include <Controls.hpp>
#include <Graphics.hpp>
#include <Classes.hpp>
#include <SysUtils.hpp>
#include <Messages.hpp>
#include <Windows.hpp>
#include <System.hpp>
#include <swmodule.h>
#include <swdisprtf.h>
//----------------------------------------------------------------------------
class TEditEntry : public TForm
{
__published:
	TPanel *SpeedBar;
	TSpeedButton *UndoButton;
	TSpeedButton *CutButton;
	TSpeedButton *CopyButton;
	TSpeedButton *PasteButton;
	TBevel *Bevel1;
	TSpeedButton *BoldButton;
	TSpeedButton *ItalicButton;
	TSpeedButton *LeftAlign;
	TSpeedButton *CenterAlign;
	TSpeedButton *RightAlign;
	TSpeedButton *UnderlineButton;
	TSpeedButton *BulletsButton;
	TEdit *FontSize;
	TUpDown *UpDown1;
	TPanel *Ruler;
	TLabel *FirstInd;
	TLabel *LeftInd;
	TBevel *RulerLine;
	TLabel *RightInd;
	TStatusBar *StatusBar;
	TRichEdit *RichEdit1;
	TLabel *Label1;
	void __fastcall SelectionChange(TObject *Sender);
	void __fastcall AlignClick(TObject *Sender);
	void __fastcall EditUndoClick(TObject *Sender);
	void __fastcall EditCutClick(TObject *Sender);
	void __fastcall EditCopyClick(TObject *Sender);
	void __fastcall EditPasteClick(TObject *Sender);
	void __fastcall RulerResize(TObject *Sender);
	void __fastcall FormCreate(TObject *Sender);
	void __fastcall FormResize(TObject *Sender);
	void __fastcall FormPaint(TObject *Sender);
	void __fastcall BoldButtonClick(TObject *Sender);
	void __fastcall FontSizeChange(TObject *Sender);
	void __fastcall UnderlineButtonClick(TObject *Sender);
	void __fastcall ItalicButtonClick(TObject *Sender);
	void __fastcall BulletsButtonClick(TObject *Sender);
	void __fastcall FormCloseQuery(TObject *Sender, bool &CanClose);
	void __fastcall RulerItemMouseDown(TObject *Sender, TMouseButton Button, TShiftState Shift, int X, int Y);
	void __fastcall RulerItemMouseMove(TObject *Sender, TShiftState Shift, int X, int Y);
	void __fastcall FirstIndMouseUp(TObject *Sender, TMouseButton Button, TShiftState Shift, int X, int Y);
	void __fastcall LeftIndMouseUp(TObject *Sender, TMouseButton Button, TShiftState Shift, int X, int Y);
	void __fastcall RightIndMouseUp(TObject *Sender, TMouseButton Button, TShiftState Shift, int X, int Y);
    void __fastcall FormActivate(TObject *Sender);
	   
private:
	AnsiString FFileName;
	bool FUpdating;
	int FDragOfs;
	bool FDragging;
	TTextAttributes *__fastcall CurrText(void);
	void __fastcall CheckFileSave(void);
	void __fastcall SetupRuler(void);
	void __fastcall SetEditRect(void);
	void __fastcall ShowHint(TObject *Sender);

public:
	SWModule *Module;
	SWDispRTF *RTFDisplay;
	
	virtual __fastcall TEditEntry(TComponent *Owner);
	__fastcall ~TEditEntry();
	char *ResultBuf;
	void ExtractRTF();
};
//----------------------------------------------------------------------------
class TCharsetObject : public TObject
{
public:
    int Charset;
    __fastcall TCharsetObject(int FCharset);
};
//----------------------------------------------------------------------------
extern TEditEntry *EditEntry;
//----------------------------------------------------------------------------
#endif

==> sword-1.5.5.tar.gz: sword-1.5.5/apps/windoze/CBuilder5/BibleCS/editentryfrm.h <==
//----------------------------------------------------------------------------
//Borland C++Builder
//Copyright (c) 1987, 1998 Borland International Inc. All Rights Reserved.
//----------------------------------------------------------------------------
//----------------------------------------------------------------------------
#ifndef editentryfrmH
#define editentryfrmH
//----------------------------------------------------------------------------
#include <Outline.hpp>
#include <Grids.hpp>
#include <Buttons.hpp>
#include <ExtCtrls.hpp>
#include <StdCtrls.hpp>
#include <ComCtrls.hpp>
#include <Menus.hpp>
#include <Dialogs.hpp>
#include <Forms.hpp>
#include <Controls.hpp>
#include <Graphics.hpp>
#include <Classes.hpp>
#include <SysUtils.hpp>
#include <Messages.hpp>
#include <Windows.hpp>
#include <System.hpp>
#include <swmodule.h>
#include <swdisprtf.h>
#include "rxricheditx.h"
//----------------------------------------------------------------------------
class TEditEntryForm : public TForm
{
__published:
	TPanel *SpeedBar;
	TSpeedButton *UndoButton;
	TSpeedButton *CutButton;
	TSpeedButton *CopyButton;
	TSpeedButton *PasteButton;
	TBevel *Bevel1;
	TSpeedButton *BoldButton;
	TSpeedButton *ItalicButton;
	TSpeedButton *LeftAlign;
	TSpeedButton *CenterAlign;
	TSpeedButton *RightAlign;
	TSpeedButton *UnderlineButton;
	TSpeedButton *BulletsButton;
	TEdit *FontSize;
	TUpDown *UpDown1;
	TPanel *Ruler;
	TLabel *FirstInd;
	TLabel *LeftInd;
	TBevel *RulerLine;
	TLabel *RightInd;
	TStatusBar *StatusBar;
	TLabel *Label1;
	TPanel *pnlRichEdit;
	void __fastcall SelectionChange(TObject *Sender);
	void __fastcall AlignClick(TObject *Sender);
	void __fastcall EditUndoClick(TObject *Sender);
	void __fastcall EditCutClick(TObject *Sender);
	void __fastcall EditCopyClick(TObject *Sender);
	void __fastcall EditPasteClick(TObject *Sender);
	void __fastcall RulerResize(TObject *Sender);
	void __fastcall FormCreate(TObject *Sender);
	void __fastcall FormResize(TObject *Sender);
	void __fastcall FormPaint(TObject *Sender);
	void __fastcall BoldButtonClick(TObject *Sender);
	void __fastcall FontSizeChange(TObject *Sender);
	void __fastcall UnderlineButtonClick(TObject *Sender);
	void __fastcall ItalicButtonClick(TObject *Sender);
	void __fastcall BulletsButtonClick(TObject *Sender);
	void __fastcall FormCloseQuery(TObject *Sender, bool &CanClose);
	void __fastcall RulerItemMouseDown(TObject *Sender, TMouseButton Button, TShiftState Shift, int X, int Y);
	void __fastcall RulerItemMouseMove(TObject *Sender, TShiftState Shift, int X, int Y);
	void __fastcall FirstIndMouseUp(TObject *Sender, TMouseButton Button, TShiftState Shift, int X, int Y);
	void __fastcall LeftIndMouseUp(TObject *Sender, TMouseButton Button, TShiftState Shift, int X, int Y);
	void __fastcall RightIndMouseUp(TObject *Sender, TMouseButton Button, TShiftState Shift, int X, int Y);
    void __fastcall FormActivate(TObject *Sender);
	   
private:
	TRxRichEditX *RichEdit1;
	AnsiString FFileName;
	bool FUpdating;
	int FDragOfs;
	bool FDragging;
	TRxTextAttributes *__fastcall CurrText(void);
	void __fastcall CheckFileSave(void);
	void __fastcall SetupRuler(void);
	void __fastcall SetEditRect(void);
	void __fastcall ShowHint(TObject *Sender);

public:
	SWModule *Module;
	SWDispRTF *RTFDisplay;
	
	virtual __fastcall TEditEntryForm(TComponent *Owner);
	__fastcall ~TEditEntryForm();
	char *ResultBuf;
	void ExtractRTF();
};
//----------------------------------------------------------------------------
class TCharsetObject : public TObject
{
public:
    int Charset;
    __fastcall TCharsetObject(int FCharset);
};
//----------------------------------------------------------------------------
extern TEditEntryForm *EditEntryForm;
//----------------------------------------------------------------------------
#endif
